This function prints results of classical or ordered multiple correspondence analysis.
The input parameter is the name of the output of the main function MCAvariants.
# S3 method for MCAvariants
print(x, printdims = 2,...)The value of output returned depends on the kind of multiple correspondence analysis performed.
The Burt data table.
Rows in principal coordinates: the first 10.
Column in principal coordinates.
Polynomial functions of each variable.
When catype is omca.
The percentage of individuals belonging to each cluster. When catype is omca.
The decomposition of total inertia via orthogonal polynomials. When catype is omca.
Degree of Freedom of Polynomial Component. When catype is omca.
Inertia values of super-indicator and Burt table.
Adjusted Inertia values, percentages and cumulative.
The degree of freedom of total inertia.
Total inertia of Super-Indicator table
Total inertia of BURT table.
Chi-square values of BURT Inertia.
Chi-square values of total Inertia of Burt table.
The output of the main function CAvariants.
The number of dimensions, printdims, that are used to generate the correspondence plot
and for summarising the numerical output of the analysis. By default, printdims = 2.
Further arguments passed to or from other methods.
Rosaria Lombardo
This function uses another function (called printwithaxes) for specifying the number of matrix dimensions to print.
Lombardo R and Meulman JJ (2010) Journal of Classification, 27, 191-210.
Beh EJ Lombardo R (2014) Correspondence Analysis, Theory, Practice and New Strategies. Wiley
res=MCAvariants(satisfaction, catype = "omca", np = 5, vordered=c(TRUE,TRUE,TRUE,TRUE,TRUE))
print(res)
Run the code above in your browser using DataLab